@@ -193,7 +193,15 @@ namespace giac {
     add_print(s, v.front(),contextptr);
     for (int i=1;i<l;++i){
       s += '+';
+      bool par=false;
+      if (v[i].type==_SYMB){
+	const unary_function_ptr & u=v[i]._SYMBptr->sommet;
+	if (u==at_superieur_egal || u==at_superieur_strict || u==at_inferieur_strict || u==at_inferieur_egal)
+	  par=true;
+      }
+      if (par) s+='(';
       add_print(s,v[i],contextptr);
+      if (par) s+=')';
     }
     return s;
   }
@@ -353,10 +361,18 @@ namespace giac {
     }
 #endif
     bool argpar = ( (arg.type>_CPLX && arg.type!=_FLOAT_) || !is_positive(arg,contextptr)) && arg.type!=_IDNT ;
-#if defined EMCC || defined GIAC_GGB
+#if defined EMCC || defined GIAC_GGB 
     bool need=need_parenthesis(arg) || arg.type==_SYMB;
     if (pui==plus_one_half){
+#ifdef KHICAS // inactive code
+      need=true;
+      s += char(226);
+      s += char(136);
+      s += char(154);
+      s+= '(';
+#else
       s += (need?"√(":"√");
+#endif
       add_print(s,arg,contextptr);
       s += (need?")":"");
       return s;
@@ -413,7 +429,12 @@ namespace giac {
 #ifdef GIAC_HAS_STO_38
 	s += '^';
 #else
-	if (python_compat(contextptr))
+	if (
+	    python_compat(contextptr)
+#ifdef KHICAS
+	    && os_shell
+#endif
+	    )
 	  s += "**";
 	else 
 	  s += __pow.s;
@@ -429,7 +450,11 @@ namespace giac {
 #ifdef GIAC_HAS_STO_38
 	s += '^';
 #else
-	if (python_compat(contextptr))
+	if (python_compat(contextptr)
+#ifdef KHICAS
+	    && os_shell
+#endif
+	    )
 	  s += "**";
 	else
 	  s += __pow.s;
@@ -445,7 +470,12 @@ namespace giac {
 #ifdef GIAC_HAS_STO_38
     s += '^';
 #else
-    s += __pow.s;
+    s +=
+      python_compat(contextptr)
+#ifdef KHICAS
+      && os_shell
+#endif
+      ?"**":__pow.s;
 #endif
     bool puipar = pui.type==_SYMB || pui.type==_FRAC || pui.type==_CPLX || (pui.type==_VECT && pui.subtype==_SEQ__VECT);
     if (puipar)
@@ -1633,7 +1663,7 @@ namespace giac {
     if (g.type==_FRAC)
       return 1+taille(g._FRACptr->num,max)+taille(g._FRACptr->den,max);
     if (g.type==_SYMB){
-      if (g.is_symb_of_sommet(at_curve))
+      if (max && g.is_symb_of_sommet(at_curve))
 	return 10;
       return 1+taille(g._SYMBptr->feuille,max);
     }
@@ -1650,6 +1680,79 @@ namespace giac {
     return 2;
   }
 
+  int malloc_size(int s,int nalloc=2){
+    return nextpow2(s/4)*4+nalloc*16;
+  }
+
+  void tailles(const gen & g,vector<int> & v){
+    switch (g.type){
+    case _INT_: case _DOUBLE_: case _FLOAT_: case _FUNC:
+      ++v[0];
+      return;
+    case _CPLX:
+      tailles(*g._CPLXptr,v);
+      tailles(*(g._CPLXptr+1),v);
+      ++v[1];
+      v[8] += malloc_size(sizeof(ref_complex));
+      return;
+    case _IDNT:
+      ++v[2];
+      // v[8] += malloc_size(sizeof(ref_identificateur)); // shared in syms()
+      return;
+    case _FRAC:
+      tailles(g._FRACptr->num,v);
+      tailles(g._FRACptr->den,v);
+      ++v[3];
+      v[8] += malloc_size(sizeof(ref_fraction));
+      return;
+    case _VECT: {
+      const_iterateur it=g._VECTptr->begin(),itend=g._VECTptr->end();
+      ++v[4];
+      // CERR << g._VECTptr->capacity() << " "  << itend-it  << " " << g << endl;
+#if defined IMMEDIATE_VECTOR
+      if (g._VECTptr->capacity()<=(IMMEDIATE_VECTOR*sizeof(int))/sizeof(gen))
+	v[8] += malloc_size(sizeof(ref_vecteur),1);
+      else
+#endif
+	v[8] += malloc_size(sizeof(ref_vecteur))+g._VECTptr->capacity()*sizeof(gen);
+      for (;it!=itend;++it){
+	tailles(*it,v);
+      }
+      return;
+    }
+    case _SYMB:
+      tailles(g._SYMBptr->feuille,v);
+      ++v[5];
+      v[8] += malloc_size(sizeof(ref_symbolic));
+      return;
+    case _STRNG:
+      v[8] += g._STRNGptr->capacity() + malloc_size(sizeof(ref_string));
+      ++v[6] ;
+      return;
+    default:
+      ++v[7];
+    }
+  }
+
+  int bytesize(const gen & g){
+    vector<int> v(9);
+    tailles(g,v);
+    return v[8];
+  }
+  
+  vecteur tailles(const gen & g){
+    vector<int> v(9); // atomic, idnt, frac, vector, symb, string, other, all
+    tailles(g,v);
+    vecteur w;
+    vector_int2vecteur(v,w);
+    return makevecteur(makevecteur(string2gen("atom",false),string2gen("cplx",false),
+				   string2gen("idnt",false),string2gen("frac",false),
+				   string2gen("vector",false),string2gen("symb",false),
+				   string2gen("strng",false),string2gen("other",false),
+				   string2gen("total",false))
+		       ,w);
+  }
+
   int print_max_depth=100;
   unsigned depth(const gen & g,unsigned add,unsigned max){
     gen g_(g);
